package it.dtt.ca;

import it.dtt.ca.event.CAListener;
import it.dtt.ca.exception.*;
import it.dtt.ca.ppv.Product;
import it.dtt.ca.request.CARequest;
import it.dtt.ca.response.ResponseEvent;
import it.dtt.ca.response.ResponseListener;
import it.dtt.ca.util.ParentalControlLevel;
//import mhwp.lang.MhRuntime;

import org.davic.resources.ResourceClient;

import javax.tv.service.selection.ServiceContext;


/**
 * This class provides access to the Conditional Access (CA) functionalities of the STB. It allows to perform five kinds of operations:
 * <UL>
 * <LI>get information about the CA kernel (provider, version, revision);
 * <LI>get information about the STB (pin, slots, serial number, parental control level);
 * <LI>perform requests to the CA kernel;
 * <LI>set listeners to specific CA events;
 * <LI>change the parental control level of the STB.
 * </UL>
 * 
 */
public abstract class CAManager extends CAObject {



    /**
     * Creates the <code>CAManager</code> object and the associated new CASession.
     * The circumstances when the ResourceClient is called should be defined in the CA system specific documentation.
     * This class is not a singleton. A device supporting multiple CA kernels shall support one instance of this class for each supported CA kernel.
     * 
     * @param resourceClient
     *            the resource client.
     */
    protected CAManager(ResourceClient resourceClient) {
    }

    /**
     * Get the client that requested this object.
     * The circumstances when the ResourceClient is called should be defined in the CA system specific documentation.
     * 
     * @return the client object.
     * @see org.davic.resources.ResourceProxy#getClient()
     */
    public ResourceClient getClient() {
        return null;
    }

    /**
     * Get all Personal Identification Numbers that are stored on the STB.
     * 
     * @return a vector of Pins.
     * @throws SessionClosedException
     *             if the session is closed.
     */
    public abstract Pin[] getPins() throws SessionClosedException;

    /**
     * Retrieves serial number of the set top box.
     * 
     * @return the set top box serial number.
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
    public String getIrdSerialNumber() throws SessionClosedException {
        return null;
    }

    /**
     * This method returns an array containing references to the smart card reader slots present in the set top box (normally just one).
     * This method shall return all smart card slots regardless of which smartcard (if any) they contain.
     * 
     * @return an array with the slots instances
     * @throws SessionClosedException
     *             thrown if the session was closed.
     * @see Slot
     */
    public abstract Slot[] getSlots() throws SessionClosedException;

    /**
     * Register a listener to the Conditional Access related events.
     * If listener already exists, do nothing.
     * 
     * @param listener
     *            the only listener to CA related events
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
  public void addCAListener(CAListener listener) throws SessionClosedException {
      // body
    }

  /**
   * @deprecated use addCAListener
   * Register a listener to the Conditional Access related events.
   * If listener already exists, do nothing.
   * 
   * @param listener
   *            the only listener to CA related events
   * @throws SessionClosedException
   *             thrown if the session was closed.
   */
public void setCAListener(CAListener listener) throws SessionClosedException {
    // body
  }

    /**
     * Removes the specified CAListener if attached, otherwise an exception is thrown.
     * If listener does not exist, do nothing.
     * 
     * @throws SessionClosedException
     *             thrown if the session was closed.
     * @throws NoListenerAttachedException thrown if no listener is currently attached            
     */
  public void removeCAListener(CAListener listener) throws SessionClosedException, NoListenerAttachedException {
      // body
    }

  /**
   * @deprecated
   * Removes the last CAListener attached. If no listener is attached an exception is thrown.
   * If listener does not exist, do nothing.
   * 
   * @throws SessionClosedException
   *             thrown if the session was closed.
   * @throws NoListenerAttachedException thrown if no listener is currently attached            
   */
public void removeCAListener() throws SessionClosedException, NoListenerAttachedException {
    // body
  }

    /**
     * @deprecated replaced by getCurrentProduct
     * 
     * Retrieve a Product object describing the event currently on air,
     * independently of the way it is offered (Impulse Pay per View, Ordered Pay per View,
     * Pay per Time, etc.) 
     * A NULL value is returned if no service is currently selected in this service context or of the currently selected service context is not something which can be bought through the CA system represented by this CAManager.
	 * In a multi-tuner receiver, the target service is the one in which the application itself is broadcasted.
     *
     * Note: this method has been replaced by the getCurrentProducts method but is retained
     * here for backward compatability.
     * 
     * @return a Product object describing the current service
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
  public Product getCurrentEvent() throws SessionClosedException {
        return null;
    }

    /**
	 * @deprecated replaced by getNextProduct
	 * 
     * Retrieve a Product object describing the event that will be next on air,
     * independently of the way it is offered (Impulse Pay per View, Ordered Pay per View,
     * Pay per Time, etc.).
     * A NULL value is returned if no service is currently selected in this service context or of the currently selected service context is not something which can be bought through the CA system represented by this CAManager.
     * In a multi-tuner receiver, the target service is the one in which the application itself is broadcasted.
     *
     * Note: this method has been replaced by the getNextProducts method but is retained
     * here for backward compatability.
     *
     * @return a Product object describing the next service
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
  public Product getNextEvent() throws SessionClosedException {
        return null;
    }

    /**
     * Retrieve Product objects describing the event currently on air(in the default Service Context),
     * independently  of the way it is offered (Impulse Pay per View, Ordered Pay per View,
     * Pay per Time, etc.) 
     * A NULL value is returned if no service is currently selected in this service context or of the currently selected service context is not something which can be bought through the CA system represented by this CAManager.
     * The default implementation returns null after verifying the session status.
	 * In a multi-tuner receiver, the target service is the one in which the application itself is broadcasted.
     *
     * Example, the same Event may be purchased indiviually or in a Package, with different prices associated.
     *
     * @return Product objects describing the current service
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
  public Product[] getCurrentProducts() throws SessionClosedException {
        return null;
    }

    /**
     * Retrieve Product objects describing the event currently on air(in the specified Service Context), independently
     * of the way it is offered (Impulse Pay per View, Ordered Pay per View,
     * Pay per Time, etc.).
     * A NULL value is returned if no service is currently selected in this service context or of the currently selected service context is not something which can be bought through the CA system represented by this CAManager.
     * The default implementation returns null after verifying the session status.
     *
     * Example, the same Event may be purchased indiviually or in a Package, with different prices associated.
     *
     * @return Product objects describing the current service
     * @throws SessionClosedException thrown if the session was closed.
     * @throws NoSuchServiceContextException - if the indicated Service Context does not exist or is not available.

     */
    public Product[] getCurrentProducts(ServiceContext serviceContext) throws SessionClosedException, NoSuchServiceContextException {
        return null;
    }

    /**
     * Retrieve Product objects describing the service that will be next on air, independently of the way it is offered (Impulse Pay per View, Ordered Pay per View, Pay per Time, etc.) 
     * A NULL value is returned if no service is currently selected in this service context or of the currently selected service context is not something which can be bought through the CA system represented by this CAManager.
	 * In a multi-tuner receiver, the target service is the one in which the application itself is broadcasted.
     * 
     * @return Product objects describing the next service
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
  public Product[] getNextProducts() throws SessionClosedException {
        return null;
    }

    /**
     * Retrieve Product objects describing the service that will be next on air(in the specified Service Context),
     * independently of the way it is offered (Impulse Pay per View, Ordered Pay per View, Pay per Time, etc.)
     * A NULL value is returned if no service is currently selected in this service context or of the currently selected service context is not something which can be bought through the CA system represented by this CAManager.   
     * if no service is currently on air, or if the current service is unknown.
     * The default implementation returns null after verifying the session status.
     *
     * @return Product objects describing the current service
     * @throws SessionClosedException thrown if the session was closed.
     * @throws NoSuchServiceContextException - if the indicated Service Context does not exist or is not available.
     */
  public Product[] getNextProducts(ServiceContext serviceContext) throws SessionClosedException, NoSuchServiceContextException {
        return null;
    }

    /**
     * Perform the specified request synchronously and return the response. The method blocks until the response is received or the timeout expires (in this case, the TimeoutExpiredException is
     * thrown).
     * 
     * @param request
     *            the request which should be performed.
     * @param timeoutms
     *            the required timeout in milliseconds, after which the TimeoutExpiredException is thrown.
     * @return the response event.
     * @throws SessionClosedException
     *             thrown if the session was closed.
     * @throws InvalidTransactionDataException
     *             if some data used for transaction is wrong (ie. any null field for credit card data)
     * @throws InvalidRequestParametersException
     *             if the request paramters are invalid.
     * @throws CardNotFoundException
     *             if the correct card is not inserted.
     * @throws TimeoutExpiredException
     *             if the timeout expires.
     * @throws CARequestAlreadyStartedException
     * 				if the request is already started            
     */
    public ResponseEvent performRequest(CARequest request, int timeoutms) throws SessionClosedException, InvalidRequestParametersException, InvalidTransactionDataException, CardNotFoundException,CARequestAlreadyStartedException,
            TimeoutExpiredException {
        return null;
    }

    /**
     * Perform the specified request asynchronously and send the response to the given ResponseListener. If the request is of RcRechargeRequest type, also an event of type RechargeEvent should be
     * thrown to any registered RechargeListener.
     * 
     * @param request
     *            the request which should be performed.
     * @param listener
     *            the object waiting for the response to this request.
     * @throws SessionClosedException
     *             thrown if the session was closed.
     * @throws InvalidRequestParametersException
     *             if the request paramters are invalid.
     * @throws InvalidTransactionDataException
     *             if some data used for transaction is wrong (ie. any null field for credit card data)
     * @throws CardNotFoundException
     *             if the correct card is not inserted.
     * @throws CARequestAlreadyStartedException
     * 				if the request is already started   
     */
    public void performRequest(CARequest request, ResponseListener listener) throws SessionClosedException, InvalidRequestParametersException, InvalidTransactionDataException, CardNotFoundException,CARequestAlreadyStartedException {
      // body
    }

    /**
     * Perform the specified request asynchronously using a return channel connection and send the response to the given ResponseListener. The return channel related events are sent to the given
     * ConnectionListener. If the request is of RcRechargeRequest type, also an event of type RechargeEvent should be thrown to any registered RechargeListener.
     * 
     * @param request
     *            the request which should be performed
     * @param listener
     *            the object waiting for the response to this request.
     * @param params
     *            the parameters used for the return channel connection
     * @param rclistener
     *            the object waiting for the return channel related events
     * @throws SessionClosedException
     *             thrown if the session was closed.
     * @throws InvalidRequestParametersException
     *             if the request paramters are invalid.
     * @throws InvalidTransactionDataException
     *             if some data used for transaction is wrong (ie. any null field for credit card data)
     * @throws CardNotFoundException
     *             if the correct card is not inserted.
     * @throws CARequestAlreadyStartedException
     * 				if the request is already started   
     */
    public void performRequest(CARequest request, ResponseListener listener, org.dvb.net.rc.ConnectionParameters params, org.dvb.net.rc.ConnectionListener rclistener) throws SessionClosedException,
            InvalidRequestParametersException, InvalidTransactionDataException, CardNotFoundException,CARequestAlreadyStartedException {

    }

    /**
     * Get the current parental control level.
     * 
     * @return the parental control level.
     * @throws SessionClosedException
     *             thrown if the session was closed.
     */
  public ParentalControlLevel getParentalControlLevel() throws SessionClosedException
    {
        return null;
    }

    /**
     * Set the parental control level.
     * This allows the user to set which kind of PPV events should require an extra PIN
     * input for viewing. To change the parental control level, a PIN input may be
     * required.
     * 
     * @param level
     *            the new parental control level.
     * @param pin
     *            the parental control pin.
     * @throws SessionClosedException
     *             thrown if the session was closed.
     * @throws InvalidPinException
     *             thrown if the specified PIN is invalid.
     */
  public void setParentalControlLevel(ParentalControlLevel level, byte[] pin) throws SessionClosedException, InvalidPinException
    {
    }

    /**
     * Get the name of the CA provider ("Nagra", "Irdeto", etc).
     * 
     * @return a string containing the name of the CA provider.
     */
    public abstract String getCAProvider();

    /**
     * Get the version of the CA kernel.
     * 
     * @return CA version.
     */
    public abstract String getCAVersion();

    /**
     * Get the revision of the CA kernel.
     * 
     * @return CA revision.
     */
    public abstract String getCARevision();
    
    /**
     * Closes the connection with a client that was interacting with the Conditional Access
     * 
     * The circumstances when the ResourceClient is called should be defined in the CA system specific documentation.
     */
    synchronized void closeClient(ResourceClient resourceClient) {
    }

}
