package it.dtt.ca;

/**
 * Represents the CA session. Every {@link it.dtt.ca.CAObject}
 * has a session object connected with it. This session object is used
 * to close session or to check if the session is already closed.
 *
 * @see it.dtt.ca.CAObject#checkSession()
 * @see it.dtt.ca.CAObject#sessionClosed()
 */
final class CASession
{
    private CAObject caObj;
    
    /**
     * Default constructor.
     *
     * @param caObject {@link CAObject} which opened this session.
     */
    CASession(CAObject caObject)
    {
        super();
        caObj = caObject;
    }

    /**
     * Closes the session.
     */
    void closeSession()
    {
        caObj = null;
    }

    /**
     * Determines if the session is open.
     *
     * @return <code>true</code> if the session is opened;
     *          <code>false</code> otherwise.
     */
    boolean isSessionOpen()
    {
        return caObj != null;
    }

    /**
     * Get the CAObject which opened this session.
     * @return Returns the caObject.
     */
    public CAObject getCaObject()
    {
        return caObj;
    }
}
