package it.dtt.ca.event;

import it.dtt.ca.CAManager;

/**
 * This event is used to notify a listener about a CA module status changes regarding the access,
 * descrambling and purchasing periods.
 * Under some circumstances, a single event in the CA system may result in
 * multiple CAAccessEvents being posted. For example, successful purchase of a
 * current program could result in both DESCRAMBLING_BEGIN and ACCESS_GRANTED.
 * 
 */
public class CAAccessEvent extends CAEvent {


    /**
     * Used by the CA to notify an unknown event to the application.
     */
    public final static int CA_GENERIC_EVENT = 1;

    /**
     * Notifies that the current service has began being descrambled
     */
    public final static int DESCRAMBLING_BEGIN = 2;
    /**
     * Notifies that the descrambling process has been stopped for the current
     * service
     */
    public final static int DESCRAMBLING_END = 3;
    /**
     * Notifies that the free window period for current PPV event is started
     */
    public final static int FREE_WINDOW_BEGIN = 4;
    /**
     * Notifies that the free window period for current PPV event is ended
     */
    public final static int FREE_WINDOW_END = 5;
    /**
     * Notifies that the purchase period for current PPV event is started
     */
    public final static int PURCHASE_PERIOD_BEGIN = 6;
    /**
     * Notifies that the purchase period for current PPV event is ended
     */
    public final static int PURCHASE_PERIOD_END = 7;

    /**
     * Notifies that the CA is entitled to descramble the current PPV event.
     */
    public final static int ACCESS_GRANTED = 8;


    /**
     * Notifies that the CA is not entitled to descramble the current PPV event.
     */
    public final static int ACCESS_DENIED = 9;

    /**
     * Notifies that the CA is not entitled to descramble the current PPV event
     * due to parental rating.
     */
    public final static int ACCESS_DENIED_FOR_PARENTAL_RATING = 10;

    /**
     * Notifies that a card is needed.
     */
    public final static int CARD_NEEDED = 11;

    /**
     * Notifies that the CA is not entitled to descramble the current PPV event
     * due to smart card issue. The smart card status can then be retrieved using
     * specific methods.
     */
    public final static int ACCESS_DENIED_FOR_SMART_CARD_ERROR = 12;

    /**
     * Notifies that the signal is not scrambled
     */
    public final static int ACCESS_CLEAR = 13;

    /**
     * Notifies that the signal is scrambled in free mode
     */
    public final static int ACCESS_FREE = 14;

    /**
     * Creates a CAEvent instance
     *
     * @param caManager the CAManager
     * @param type      the type of event
     */

    protected CAAccessEvent(it.dtt.ca.CAManager caManager, int type) {
    	super(caManager, null, null);
    }
    
    protected   CAAccessEvent(it.dtt.ca.CAManager caManager, Object data, String description){
        super(caManager, data, description);
    }

    /**
     * Retrieves the CAManager instance
     *
     * @return the CAManager
     */
    public CAManager getCAManager() {
        return null;
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#CA_ACCESS_EVENT
     */
    public int getType() {
        return CA_ACCESS_EVENT;
    }

}
