package it.dtt.ca.event;

import it.dtt.ca.CAObject;
import it.dtt.ca.CAPrivateData;

/**
 * Base class for all CA related events defined in this package
 * 
 */
public abstract class CAEvent {
    public static final int CA_ACCESS_EVENT = 3001;
    public static final int CA_PRODUCT_EVENT = 3002;
    public static final int NEW_MESSAGE_EVENT = 3003;
    public static final int PIN_REQUEST_EVENT = 3004;
    public static final int RECHARGE_EVENT = 3005;
    public static final int SLOT_EVENT = 3006;
    public static final int HISTORY_UPDATE_EVENT = 3008;
    public static final int SMART_CARD_STATUS_EVENT = 3009;

    /**
     * Creates a CAEvent instance
     *
     * @param source      the object which generated this event
     * @param data        the event data
     * @param description description related to the event
     */
    protected CAEvent(CAObject source, Object data, String description) {
    }

    /**
     * Creates a CAEvent instance
     *
     * @param source      the object which generated this event
     * @param data        the event data
     * @param description description related to the event
     * @param privateData    Private Data of the specific event
     */
    protected CAEvent(CAObject source, Object data, String description, CAPrivateData privateData) {
    }

    /**
     * Gets the description of the event
     *
     * @return string describing the event
     */
    public String getDescription() {
        return null;
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#CA_ACCESS_EVENT
     * @see it.dtt.ca.event.CAEvent#CA_PRODUCT_EVENT
     * @see it.dtt.ca.event.CAEvent#NEW_MESSAGE_EVENT
     * @see it.dtt.ca.event.CAEvent#PIN_REQUEST_EVENT
     * @see it.dtt.ca.event.CAEvent#RECHARGE_EVENT
     * @see it.dtt.ca.event.CAEvent#SLOT_EVENT
     * @see it.dtt.ca.event.CAEvent#HISTORY_UPDATE_EVENT
     * @see it.dtt.ca.event.CAEvent#SMART_CARD_STATUS_EVENT
     */
    public abstract int getType();

    /**
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return null;
    }

    /**
     * Returns the object which generated this event.
     *
     * @return the object which generated this event.
     */
    protected CAObject getSource()
    {
        return null;
    }

    /**
     * Returns the data.
     *
     * @return the data.
     */
    protected Object getData()
    {
        return null;
    }

    /**
     * Returns the Private Data for this event.
     *
     * @return Private Data.
     */
    public CAPrivateData getPrivateData() {
        return null;
    }

    /**
     * Sets the Private Data for this event.
     */
    protected void setPrivateData(CAPrivateData privateData) {
    }
}