package it.dtt.ca.event;

import it.dtt.ca.CAManager;
import it.dtt.ca.ppv.Product;

/**
 * Notifies events related to a Product.
 * 
 */
public class CAProductEvent extends CAEvent {


    /**
     * Notifies that the current PPV event reached the end.
     */
    public final static int EVENT_END = 50;

    /**
     * Notifies that the current PPV event has been stopped by the user (e.g. by the remote control)
     */
    public final static int EVENT_STOPPED = 51;

    /**
     * Notifies that a new PPV event just started.
     */
    public final static int EVENT_BEGIN = 52;

    /**
     * This notifies that the offered products' list has changed
     */
    public final static int PRODUCTS_OFFERS_LIST_CHANGED = 53;


    /**
     * Constructor for a CAProductEvent
     *
     * @param caManager the CAManager
     * @param product   the product to which the event refers
     */
    protected CAProductEvent(it.dtt.ca.CAManager caManager, it.dtt.ca.ppv.Product product) {
        super(caManager, product, null);
    }

    /**
     * Retrieves the CAManager
     *
     * @return the CAManager
     */
    public CAManager getManager() {
        return (CAManager)getSource();
    }

    /**
     * @deprecated
     * Retrieves getProducts[0] Product object
     *
     * @return getProducts[0] Product object
     */
    public Product getProduct() {
        return null;
    }
    /**
     * Retrieves the products
     *
     * @return the products related to the event
     */
    public Product[] getProducts() {
        return new Product[]{(Product)getData()};
    }
    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#CA_PRODUCT_EVENT
     */
    public int getType() {
        return CA_PRODUCT_EVENT;
    }

}
