package it.dtt.ca.event;


import it.dtt.ca.SmartCard;
import it.dtt.ca.util.Wallet;

/**
 * Notifies that the credit on the smart card changed. 
 * 
 */
public class CreditsEvent extends SmartCardEvent {
	
	/**
	 * Notifies that the credit on the card is changed. This value should be returned by getType method.
	 */
	public static final int CREDIT_CHANGED = 100;
	
    /**
     * @param smartCard the smart card generating the event
	 * @param data        event related data
     * @param description description of the event
     * @param wallet    the wallet generating the event on the given card
     */
    protected CreditsEvent(SmartCard smartCard, java.lang.Object data, java.lang.String description, Wallet wallet) {
        super(smartCard, wallet, null);
    }

    /**
     * Retrieves the wallet on the given card, generating the credit update event
     *
     * @return the wallet
     */
    public Wallet getWallet() {
        return (Wallet) getData();
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event, which shall always have type CAEvent.CREDITS_EVENT.
     */
    public int getType() {
        return CREDIT_CHANGED;
    }

}
