package it.dtt.ca.event;


import it.dtt.ca.SmartCard;
import it.dtt.ca.history.History;

/**
 * This event notifies that an history stored on the card is changed.
 * 
 */

public class HistoryUpdateEvent extends SmartCardEvent {


/**
* Notifies that the purchase list stored on the card is changed.
*/
public final static int PURCHASE_HISTORY_CHANGED = 150;

/**
* Notifies that the recharge list stored on the card is changed.
*/
public final static int RECHARGE_HISTORY_CHANGED = 151;

/**
* Notifies that the message list stored on the card is changed.
*/
public final static int MESSAGE_HISTORY_CHANGED = 152;


    /**
     * Generate an HistoryUpdateEvent instance.
     *
     * @param smartCard the smart card generating the event.
	 * @param data        event related data
     * @param description description of the event
     * @param history   the updated history of messages.
     */
    protected HistoryUpdateEvent(SmartCard smartCard, java.lang.Object data, java.lang.String description, History history) {
        super(smartCard, history, null);
    }

    /**
     * Retrieves the history that has been updated on the smart card
     *
     * @return the history
     */
    public History getHistory() {
        return (History) getData();
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#HISTORY_UPDATE_EVENT
     */
    public int getType() {
        return HISTORY_UPDATE_EVENT;
    }

}
