/*
 * Created on Mar 30, 2005
 */
package it.dtt.ca.event;

import it.dtt.ca.*;

/**
 * This event is thrown by the CA to notify that a PIN input is required in order to proceed.
 * The Pin object to use is provided by this class.
 * 
 */
public class PinRequestEvent extends CAEvent {


    /**
     * Ask the application to enter the PIN.
     */
    public static final int PIN_REQUEST = 251;

    /**
     * Creates an istance of the PinRequestEvent
     *
     * @param caManager the CaManager
     * @param pin       the pin
     */
    protected PinRequestEvent(it.dtt.ca.CAManager caManager, it.dtt.ca.Pin pin) {

        super(caManager, pin, null);
    }


    /**
     * Get the PIN object that requires entering the correct PIN.
     *
     * @return the PIN object.
     */
    public Pin getPin() {
        return (Pin) getData();
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#PIN_REQUEST_EVENT
     */
    public int getType() {
        return PIN_REQUEST_EVENT;
    }

}
