package it.dtt.ca.event;

import it.dtt.ca.util.Money;

/**
 * This event is used to notify the box that a recharge process has been done; this
 * is useful in case of OTA recharges and should not be used in case of return channel
 * recharges which are managed via a request/response mechanism.
 * 
 */

public class RechargeEvent extends CAEvent {
    /**
     * The recharge has been done by the broadcaster for free for promotional purpose
     */
    public final static int PROMOTIONAL_RECHARGE = 300;
    /**
     * The recharge has been done by the broadcaster to cancel debit
     */
    public final static int DEBIT_CANCELLATION_RECHARGE = 301;
    /**
     * The recharge has arrived after a request done by the user (both via OTA and via RC)
     */
    public final static int REQUESTED_RECHARGE = 302;

    /**
     * Creates a RechargeEvent object.
     *
     * @param caManager the CaManager
     * @param money     the value of the recharge
     */

    protected RechargeEvent(it.dtt.ca.CAManager caManager, it.dtt.ca.util.Money money) {
        super(caManager, money, null);
    }

    /**
     * Retrieves the value charged on the card.
     *
     * @return the value
     */
    public Money getValue() {
        return (Money) getData();  // body
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#RECHARGE_EVENT
     */
    public int getType() {
        return RECHARGE_EVENT;
    }

}