package it.dtt.ca.event;

/**
 * Notifies the status of the smart card.
 * 
 */
public class SmartCardStatusEvent extends SmartCardEvent {
    /**
     * Notifies that the smart card is valid.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int VALID = 400;

    /**
     * Notifies that the smart cart is not valid. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int INVALID = 401;

    /**
     * Notifies that the smart card is expired. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int EXPIRED = 402;

    /**
     * Notifies that the smart card is blacklisted. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int BLACKLISTED = 403;

    /**
     * Notifies that the smart card is suspended. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int SUSPENDED = 404;

    /**
     * Notifies that the smart card has never been paired with box. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int NEVER_PAIRED = 405;

    /**
     * Notifies that the smart card is not actually paired with the box. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int NOT_PAIRED = 406;

    /**
     * Notifies that the smart card is not certified. When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int NOT_CERTIFIED = 407;

    /**
     * Notifies that the smart card has filled up memory.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int MEMORY_FULL = 408;

    /**
     * Notifies that there is an unknown error with the smart card.
     * When in this state, the smart card cannot perform any further operation.
     * This value may also be returned when a smart card check is performed.
     * This is a type which can be returned by the getType method of this class.
     */
    public final static int GENERIC_CARD_ERROR = 409;

      /**
	  * Notifies that the pin of the smart card is changed (i.e. to have notification on
      * reset by SMS).
      * This is a type which can be returned by the getType method of this class.
 	  */
	  public final static int PIN_CHANGED = 410;
	  
    /**
     * Constructor for SmartCardStatusEvent object
     *
     * @param smartCard the smart card generating the event
	 * @param data        event related data
     * @param description description of the event
     */
    protected SmartCardStatusEvent(it.dtt.ca.SmartCard smartCard, java.lang.Object data, java.lang.String description) {
        super(smartCard, null, null);
    }

    /**
     * Returns the type of event that's arrived.
     *
     * @return type of event.
     * @see it.dtt.ca.event.CAEvent#SMART_CARD_STATUS_EVENT
     */
    public int getType() {
        return SMART_CARD_STATUS_EVENT;
    }

}
