package it.dtt.ca.history;

import java.util.Date;

import it.dtt.ca.ppv.*;

/**
 * This object describes one item of the history regarding purchased services.
 * 
 */

public class ProductHistoryItem extends HistoryItem {    

    /**
     * Create a ProductHistoryItem.
     * @param product the Product which was purchased by the user.
     * @param itemStatus indicates whether the item was seen, lost, refunded, etc. 
     * @param orderingDate the date an time when the Product was purchased. 
     * @param status the status of this item in the history log, either READ, UNREAD, or DISPOSED.
     * @param date the time and date of storage of the item in the history log.
     */
   protected ProductHistoryItem(Product product, int itemStatus, Date orderingDate, int status, Date date) {
        super(status, date);
    }
    
    /**
     * Tells the event has already been seem
     */
    public static final int EVENT_SEEN = 600;
    /**
     * Tells the event has been purchased and it's upcoming
     */
    public static final int EVENT_UPCOMING = 601;
    /**
     * Tells the event ha been purchased and not viewd, so it's been lost and the
     * credit was deducted.
     */
    public static final int EVENT_LOST = 602;

    /**
     * Tells the event has been refunded by broadcaster.
     */
    public static final int EVENT_REFUNDED = 603;

    /**
     * Tells if the event has already been viewed, if it's upcoming, or if it's been lost.
     *
     * @return the status.
     */
    public int getItemStatus() {
        return 0;
    }

    /**
     * Retrieves all the data associated to the service.
     *
     * @return item data.
     */
    public Product getItemData() {
        return null;
    }

    /**
     * Indicate when the order has been accepted.
     * In case of subscription or PPT events, a null value is returned.
     *
     * @return date of pay per view event order.
     */
    public Date getOrderingDate() {
        return null;
    }

}