package it.dtt.ca.history;

import java.io.Serializable;
import java.util.Date;

import it.dtt.ca.util.Money;

/**
 * This is the item describing a recharge processed by the set top box
 * 
 */
public class RechargeHistoryItem extends HistoryItem implements Serializable {

    /**
     * Create a RechargeHistoryItem.
     * @param rechargeValue The amount of the recharge.
     * @param rechargeSource The source of the recharge, can be any of the values defined in {@link it.dtt.ca.event.RechargeEvent}.
     * @param transactionId the unique identifier of the recharge transaction.
     * @param status the status of this item in the history log, either READ, UNREAD, or DISPOSED.
     * @param date the time and date of storage of the item in the history log.
     */
    protected RechargeHistoryItem(Money rechargeValue, int rechargeSource, String transactionId, int status, Date date) {
        super(status, date);
    }
    
    /**
     * Retrieves the value recharged within this specific item.
     *
     * @return The recharge value.
     */
    public Money getRechargeValue() {
        return null;
    }

    /**
     * Tells if the recharge has been done by the broadcaster for free or if it was requested by user.
     *
     * @return A constant to be compared with {@link it.dtt.ca.event.RechargeEvent}.
     */
    public int getRechargeSource() {
        return 0;
    }

    /**
     * Get the unique identifier of the recharge transaction.
     *
     * @return A string containing the transaction ID.
     */
    public String getTransactionId() {
        return null;
    }

}