package it.dtt.ca.ppv;

import javax.tv.locator.Locator;

import it.dtt.ca.util.Money;
import it.dtt.ca.util.Duration;
import it.dtt.ca.exception.FieldNotPresentException;
import javax.tv.service.guide.ContentRatingAdvisory;
/**
 * This class notifies an event offered with Pay per Time mode.
 * 
 * Where methods take an array as an input parameter,
 * implementations should take a copy of the array. Where methods return an array,
 * a copy should be returned and modifications to the array should be ignored by
 * the implementation until or unless the array is passed back to the
 * implementation as a parameter to a method call.
 */
public class PPTEvent extends PPVEvent {

    /**
     * Create a PPTEvent object.
     *
     * @param id   the PPT event identifier.
     * @param name the PPT event name.
     * @param locator  the locator of this PPV event.
     * @param rating   the rating of this PPV event.
	 * @param slicePrice price for one single slice of time.
	 * @param sliceDuration duration of a single slice of time.
     */
    protected PPTEvent(String id, String name, Locator locator, ContentRatingAdvisory rating, Money slicePrice, Duration sliceDuration) {
        super(id, name, locator, rating,null,null,null);
    }

    /**
     * Returns the price per each slice of PPT event.
     *
     * @return price of a single time slice.
     * @throws it.dtt.ca.exception.FieldNotPresentException
     *
     */
    public Money getSlicePrice() throws FieldNotPresentException {
        return null;
    }

    /**
     * @deprecated no replacement
	 * 
	 * Set the price per each slice of PPT event.
     * 
     * @param slicePrice The slicePrice to set.
     */
	protected void setSlicePrice(Money slicePrice) {
    }
    
    /**
     * Returns the length of a time slice as a Duration object.
     *
     * @return duration of the time slice. 
     * @throws it.dtt.ca.exception.FieldNotPresentException if the slice duration is unknown.
     */
    public Duration getSliceDuration() throws FieldNotPresentException {
        return null;
    }


    /**
     * @deprecated no replacement
	 *
	 * Set the length ot a time slice.
     * @param sliceDuration The sliceDuration to set.
     */
    protected void setSliceDuration(Duration sliceDuration) {
    }
    /**
     * Returns the product type
     * @return product type
     * @see  it.dtt.ca.ppv.Product#PPT_EVENT
     */
    public int getType() {
        return PPT_EVENT;
    }

}
