/*
 * PPVEvent.java 30-08-2004
 *
 * COPYRIGHT (C) Videotime
 *
 * $Revision: 2.0 $ $Date: 30/08/2004 $
 */
package it.dtt.ca.ppv;

import it.dtt.ca.exception.*;
import javax.tv.locator.Locator;
import java.util.Date;
import javax.tv.service.guide.ContentRatingAdvisory;
/**
 * Class describing PPV events.
 * 
 * Where methods take an array as an input parameter,
 * implementations should take a copy of the array. Where methods return an array,
 * a copy should be returned and modifications to the array should be ignored by
 * the implementation until or unless the array is passed back to the
 * implementation as a parameter to a method call.
 */
public class PPVEvent extends Product {

    /**
     * Create a PPVEvent.
     *
     * @param id   the PPV event id.
     * @param name the PPV event name.
     * @param locator  the locator of this PPV event.
     * @param rating   the rating of this PPV event.
	 * @param startTime the start time of this PPV event.
	 * @param endTime the end time of this PPV event.
	 * @param packages the array containing all packages associated to this PPV event.
     */
    protected PPVEvent(String id, String name, Locator locator, ContentRatingAdvisory rating, Date startTime, Date endTime, PPVPackage[] packages) {
        super(id, name, null);
    }

    /**
     * Get the rating of this event.
     * Depending on the rating, the CAManager may require an extra PIN input in order to play the event.
     *
     * @return the rating of this event.
     */
    public ContentRatingAdvisory getRating() {
        return null;
    }

    /**
     * Returns the locator connected with this event.
     *
     * @return the locator.
     */
    public Locator getLocator() {
        return null;
    }

    /**
     * Provides the list of packages in which this PPV event is contained.
     *
     * @return the list of packages in which the event is contained.
     * @throws it.dtt.ca.exception.FieldNotPresentException
     *          if the information is not available.
     */
    public PPVPackage[] getPackages() throws FieldNotPresentException {
        return null;
    }


    /**
	 * @deprecated no replacement
	 *
     * Set the list of packages in which this PPV event is contained.
     * @param packages The packages to set.
     */
    protected void setPackages(PPVPackage[] packages) {
    }
    
    /**
     * Get the starting time of the PPV event.
     *
     * @return the start time and date of the PPV event.
     * @throws it.dtt.ca.exception.FieldNotPresentException
     *          if the field is not stored
     */
    public Date getStartTime() throws FieldNotPresentException {
        return null;
    }

    /**
	 * @deprecated no replacement
	 *
     * Set the starting time of the PPV event.
     * @param startTime The startTime to set.
     */
    protected void setStartTime(Date startTime) {
    }
    
    /**
     * Get the ending time of the PPV event.
     *
     * @return time and date
     * @throws it.dtt.ca.exception.FieldNotPresentException
     *          if the field is not stored
     */
    public Date getEndTime() throws FieldNotPresentException {
        return null;
    }

    /**
     * @deprecated no replacement
	 *
	 * Set the ending time of the PPV event.
     * @param endTime The endTime to set.
     */
    protected void setEndTime(Date endTime) {
    }
    
    // must implement isFree()
    public boolean isFree() throws FieldNotPresentException {
        return false; 
    }

    /**
     * Returns the product type
     * @return product type
     * @see  it.dtt.ca.ppv.Product#PPV_EVENT
     */
    public int getType() {
        return PPV_EVENT;
    }

}
