package it.dtt.ca.request;

import it.dtt.ca.CAPrivateData;

/**
 * Base class for all requests that can be performed on the CA manager.
 * 
 */
public abstract class CARequest {

    /**
     * Create a CARequest.
     * Only derived classes can be instantiated.
     */
    protected CARequest() {
    }

    /**
     * Cancel this request.
	 * This is a synchronous method. 
     */
    public final void cancel() {
    }
	
	

    /**
     * Determines if this request has been cancelled.
     *
     * @return true if it is cancelled, false otherwise.
     */
    public final boolean isCancelled() {
        return true;
    }

    /**
     * Sets the Private Data for this request.
     */
    public void setPrivateData(CAPrivateData privateData) {
    }

    /**
     * Returns the Private Data for this request.
     *
     * @return Private Data.
     */
    public CAPrivateData getPrivateData() {
        return null;
    }
}
