package it.dtt.ca.request;

import it.dtt.ca.request.CARequest;
import it.dtt.ca.exception.*;

/**
 * This class is used to manage a recharge via return channel;
 * the user (application) will enter the scratch card number
 * or the credit card data and wait till connection and recharge process to be fulfilled.
 * The connection parameters could be set by application or also
 * set by defaults (or set top box menu).
 * 
 */

public class RcRechargeRequest extends CARequest {


    /**
     * IP address for TCP/UDP connection.
     * @see RcRechargeRequest#getRcParameter
     */
    public static final int IP_ADDRESS = 700;
    /**
     * User password for login if needed.
     * @see RcRechargeRequest#getRcParameter
     */
    public static final int PASSWORD = 701;
    /**
     * Phone number of the server to call.
     * @see RcRechargeRequest#getRcParameter
     */
    public static final int PHONE_NUMBER = 702;
    /**
     * Port number for TCP/IP connection.
     * @see RcRechargeRequest#getRcParameter
     */
    public static final int PORT_NUMBER = 703;
    /**
     * User name for login if needed.
     * @see RcRechargeRequest#getRcParameter
     */
    public static final int USER = 704;

    /**
     * Using a scratch card for the transaction.
     * In this case the transaction data array contains only one field with
     * a String representing the scratch card number to be used.
     * @see #setRechargeMode
     */
    public static final int SCRATCH_CARD_MODE = 750;
    /**
     * Using a credit card for the transaction
     * In this case the transaction data array contains these fields:<br>
     * - String : surname of user<br>
     * - String : name of user<br>
     * - String : credit card number<br>
     * - GregorianCalendar : start date of credit card<br>
     * - GregorianCalendar : expiry date of credit card<br>
     * - double : recharge value requested<br>
     * @see #setRechargeMode
     */
    public static final int CREDIT_CARD_MODE = 751;


    /**
     * Basic constructor with no parameters definition. In this case they
     * should be set with setter methods or taking the default ones.
     * 
     * @see #getRcParameter
     * 
     */
    public RcRechargeRequest() {
        // body
    }

    /**
     * Constructor with parameters' setting capabilities
     *
     * @param phone      phone number to be called
     * @param user       name of the user for login
     * @param password   password used by given user for login
     * @param ip_address address of the server
     * @param port       port number of the server
     * @throws it.dtt.ca.exception.InvalidRcParametersException
     *
     */

    public RcRechargeRequest(String phone, String user, String password, String ip_address, String port) throws InvalidRcParametersException {
    }

    /**
     * Used to retrieve a parameter of the connection.
     *
     * @param what the parameter that should be retrieved
     * @return parameter value
     * @throws InvalidRcParametersException it.dtt.ca.exception.InvalidRcParametersException
     *          if there are errors in parameters definition or if the types are not required ones
     */
    public String getRcParameter(int what) throws InvalidRcParametersException {
        return null;
    }

   

    /**
     * Retrieves data set to be used for the transaction
     *
     * @return String array with all data
     */
    public String[] getTransactionData() {
        return null;
    }
    
    /**
     * This sets method to be used to recharge the card (scratch card, credit card, ...)
     * @param mode the mode to use for this transaction
     * @throws IllegalArgumentException if the recharge
     * mode is not a supported mode
     * @see #SCRATCH_CARD_MODE and #CREDIT_CARD_MODE
     */
    public void setRechargeMode(int mode) {}
   
    /**
     * Returns the mode to be used for transaction.
     * @return the mode used for this transaction
     */
    public int getRechargeMode() { return 0;}

}
