package it.dtt.ca.response;

import it.dtt.ca.request.CARequest;

/**
 * Event generated in case of failure of a request/response process.
 * 
 */

public class FailureResponseEvent extends ResponseEvent {
/* BuyRequest related events */

    /**
     * In case the application passed a NULL pin while it was needed.
     */
    public static final int PIN_REQUIRED = 900;
    /**
     * In case the entered pin code was wrong.
     */
    public static final int PIN_ERROR = 901;
    /**
     * Notifies the card is blocked.
     */
    public static final int CARD_BLOCKED = 902;
    /**
     * Notifies the card is muted.
     */
    public static final int CARD_MUTED = 909;
    /**
     * Notifies the card is expired.
     */
    public static final int CARD_EXPIRED = 903;
    /**
     * Notifies the credit is not sufficient to proceed buying the PPV event.
     */
    public static final int CREDIT_LACK = 904;
    /**
     * Notifies the card was removed during the process.
     */
    public static final int CARD_REMOVED = 905;
    /**
     * Notifies a generic communication error with the smart card.
     */
    public static final int CARD_ERROR = 906;
    /**
     * Notifies the purchase time ended while proceeding with purchase.
     */
    public static final int PURCHASE_TIME_ENDED = 907;
    /**
     * Notifies it's impossible to buy the event because the user already have rights to watch it.
     */
    public static final int ALREADY_PURCHASED = 908;



/* RcRechargeRequest related events ... oltre a CARD_BLOCKED/EXPIRED/ERROR/REMOVED*/
    /**
     * Notifies the SMS denied the recharge to success.
     */
    public static final int SMS_DENIAL = 950;
    /**
     * Notifies the recharge ended with a failure due to a connection problem.
     */
    public static final int CONNECTION_ERROR = 951;
    /**
     * Notifies the recharge ended with a failure due to a wrong scratch card number.
     */
    public static final int INVALID_SCRATCH = 952;
    /**
     * Notifies the recharge ended with a failure because the user reached the maximum
     * allowed credit.
     */
    public static final int MAXIMUM_CREDIT = 953;
    /**
     * Notifies the recharge ended with a failure because any of the parameters used in
     * the transaction were wrong.
     */
    public static final int GENERIC_TRANSACTION_PARAMETER_ERROR = 954;




/* RetrieveBookedEventsRequest related events  ... oltre a CARD_BLOCKED/EXPIRED/ERROR/REMOVED*/


    /**
     * Notifies no card is inserted
     */
    public static final int CARD_DAMAGED = 921;
    /**
     * Notifies this feature is not supported
     */
    public static final int UNSUPPORTED_FEATURE = 922;

/* RetrieveOfferedEventsRequest related events */
    /**
     * Notifies no events are offered currently.
     */
    public static final int NO_OFFERS = 923;


    /**
     * Generic error.
     */
    public static final int GENERIC_ERROR = 999;

    /**
     * Constructs a FailureResponseEvent.
     *
     * @param request   the CARequest object that generated this response.
     * @param errorCode error code for failure.
     */
    public FailureResponseEvent(CARequest request, int errorCode) {
        super(request);
    }

    /**
     * Retrieves the error code identifying the reason for which the specific
     * request failed.
     *
     * @return error code.
     */
    public int getErrorCode() {
        return 0;
    }


}