/*
 * Created on Apr 1, 2005
 */
package it.dtt.ca.response;

import it.dtt.ca.ppv.Product;
import it.dtt.ca.request.CARequest;

/**
 * This class is used to notify that a request for offered products has ended successfully,
 * and to provide the list of such offered products.
 * 
 * Where methods take an array as an input parameter,
 * implementations should take a copy of the array. Where methods return an array,
 * a copy should be returned and modifications to the array should be ignored by
 * the implementation until or unless the array is passed back to the
 * implementation as a parameter to a method call.
 */
public class OfferedProductsResponseEvent extends SuccessResponseEvent {

    /**
     * Constructs OfferedProductsResponseEvent.
     *
     * @param request  the CARequest object, that generated this response.
     * @param products the specific products that are currently offered.
     */
    public OfferedProductsResponseEvent(CARequest request, Product[] products) {
        super(request);
    }

    /**
     * Get the array of products currently offered.
     *
     * @return an array of Products, or null of no product is currently available.
     */
    public Product[] getProducts() {
        return null;
    }

}
