/*
 * Created on Apr 1, 2005
 */
package it.dtt.ca.response;

import it.dtt.ca.ppv.Product;
import it.dtt.ca.request.CARequest;

/**
 * This class is used to notify a successful response to a request for product status information.
 * 
 */
public class ProductInfoResponseEvent extends SuccessResponseEvent {

    /**
     * This is used to specify a Purchase Status which tells the product is purchasable.
     */
    public final static int PURCHASABLE = 850;

    /**
     * This is used to specify a Purchase Status which tells the product is not purchasable
     * for CAS reasons (i.e. no access rights on air to be stored on the card)
     */
    public final static int NOT_PURCHASABLE = 851;
    /**
     * This is used to specify a Purchase Status which tells the product has already been
     * purchased: the specific rights are already found on the smart card.
     */
    public final static int PURCHASED = 852;
    /**
     * This is used to specify a Purchase Status which tells the actually inserted smart card
     * has not enough credit to buy this event
     */
    public final static int LOW_CREDIT = 853;
    /**
     * This is used to specify a Purchase Status which tells the actually inserted smart card
     * has no credit (if the event costs zero this cannot be stated as a purchase status).
     */
    public final static int NO_CREDIT = 854;
    /**
     * This is used to specify a Purchase Status which tells the actually inserted smart card
     * has some condition that caused the event not to be purchasable. The reason can be retrieved
     * using dedicated getStatus method in {@link it.dtt.ca.SmartCard}.
     */
    public final static int SMART_CARD_ISSUE = 855;

    /**
     * Constructs ProductInfoResponseEvent.
     *
     * @param request the CARequest object, that generated this response.
     * @param purchaseStatus the purchase status.
     * @param accessStatus the access status.
     * @param product the product.
     * @param isCurrent whether this is the service on air on which the STB is tuned.
     */
    public ProductInfoResponseEvent(
        CARequest request,
        int purchaseStatus,
        int accessStatus,
        Product product,
        boolean isCurrent)
    {
        super(request);
    }

    /**
     * Get the access status of the Product. It must be one of the constants defined in it.dtt.ca.event.CAAccessEvent.
     *
     * @return the status of the product.
     */
    public int getAccessStatus() {
        return 0;
    }

    /**
     * Get the purchase status of this specific product compared with the
     * access rights present on the smart card and with the amount of credit left.
     *
     * @return the purchase status.
     */
    public int getPurchaseStatus() {
        return 0;
    }

    /**
     * Informs whether this product is the one which the STB is currently receiving.
     *
     * @return TRUE if this is the current service on air on which the STB is tuned.
     */
    public boolean isCurrent() {
        return true;
    }
}
