/*
 * Created on Dec 29, 2004
 * by Massimo Balestri (Telecom Italia Lab)
 */
package it.dtt.ca.util;

import java.io.Serializable;
import it.dtt.ca.exception.UnsupportedFeatureException;

/**
 * Class representing a quantity of money; the value can be indicated using a specific currency.
 * This representation has no legal value and is provided only for information.
 * This class does not provide currency exchange calculation.
 * 
 */
public class Money implements Serializable {

	/**
     * Create an instance using a specific currency and a specic number of decimals.
     * For example, the Euro and the US Dollar have 2 decimals (cents), while the Japanese Yen has no decimal.
     *
     * @param currency a string representing the currency in the ISO 4217 interational standard.
     * The currency is indicated by means of three uppercase letters,
     * e.g. EUR, USD, JPY, CHF, AUD, CAD, CNY, GBP.
     * @param numOfDecimals the number of decimals of this currency (0..3)
	 *
	 * @throws UnsupportedFeatureException if currency String is not a valid one.
     */
    protected Money(String currency, int numOfDecimals) throws UnsupportedFeatureException {
    }

    /**
     * Set a specific amount in a specific currency
     *
     * @param units the amount in units of the indicated currency, e.g. 3 = 3 EUR
     */
    public final void setValue(int units) {
    }

    /**
     * Set a specific amount in a specific currency
     * The total amount is given by the sum of units and cents.
     *
     * @param units    the amount in units of the indicated currency, e.g. 3 = 3 EUR
     * @param decimals the amount in decimals of the indicated currency, e.g. 18 = 0.18 USD (in this case numOfDecimals = 2)
     */
    public final void setValue(int units, int decimals) {
    }

    /**
     * Get the  amount in units of the adopted currency, e.g. 5 = 5 JPY
     * The total amount is given by the sum of units and cents.
     *
     * @return the part of the total amount that can be expressed in units of the selected currency
     */
    public final int getUnits() {
        return 0;
    }

    /**
     * Get the price amount in decimals of the adopted currency, e.g. 22 = 0.22 CAD
     * The total price is given by the sum of units + decimals / (10^numOfDecimals).
     *
     * @return the part of the money amount that can be expressed in decimals of a currency
     */
    public final int getDecimals() {
        return 0;
    }

    /**
     * Get the currency adopted to indicate the price.
     *
     * @return the currency in which the amount is indicated (one of EUR, USD, JPY, etc.)
     */
    public final String getCurrency() {
        return null;
    }

    /**
     * Sum this amount to the amount given as parameter.
     *
     * @param x the amount to add
     * @throws IllegalArgumentException if x is espressed in a different currency
     */
    public final void add(Money x) throws IllegalArgumentException {
    }

    /**
     * Subtract the amount given as parameter from the current amount.
     * The resulting amount must be equal or above zero.
     *
     * @param y the amount to subtract from the current amount.
     * @throws IllegalArgumentException if y is espressed in a different currency
	 * @throws ArithmeticException if the result is not equal or above zero
     */
    public final void subtract(Money y) throws IllegalArgumentException {
    }

    /**
     * Convert the money amount to a printable string.
     *
     * @return a string containing a printable version of the money amount.
     */
    public String toString() {
        return null;
    }

    /**
     * Compares this object with the specified object for order.
     *
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(Object arg0) {
        return 0;
    }

    /**
     * Indicates whether some other object is "equal to" this one.
     *
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object obj) {
        return true;
    }
    
    /**
     * Computes the hash code for this Money.
     * @return a hash code value for this object.
     */
    public int hashCode() { return 0; }

}
