/*
 * Created on Mar 25, 2005
 */
package it.dtt.ca.util;

import javax.tv.service.guide.ContentRatingAdvisory;

/**
 * This class represent a parental control setting.
 *
 * <p>Parental Control levels will depend upon the current user.
 *
 * <p>The current user is defined and retrieved using the
 * org.dvb.user.GeneralPreference("UserName", String userName).
 *
 * <p>The user name is stored by:
 * <li>GeneralPreference myPref = new GeneralPreference("UserName", "John Doe");
 * <li>UserPreferenceManager.getInstance().write(myPref);
 *
 * <p>And can be read by:
 * <li>GeneralPreference myPref = new GeneralPreference("UserName").
 * <li>UserPreferenceManager.getInstance().read(myPref);
 * <li>String myUserName = myPref.getMostFavourite();
 */
public class ParentalControlLevel {

    /**
     * This mode requires an extra PIN input for viewing all PPV events
     * except those rated "ALL_AUDIENCE".
     */
    public final static int PARENTAL_CONTROL_STRICT_MODE = 800;

    /**
     * This mode required an extra PIN input for viewing PPV events
     * rated "RESTRICTED" and "ADULTS_ONLY", and no PIN for all other events.
     */
    public final static int PARENTAL_CONTROL_INTERMEDIATE_MODE = 801;

    /**
     * This mode requires an extra PIN input for viewing PPV events
     * rated "ADULTS_ONLY", and no PIN for all other events.
     */
    public final static int PARENTAL_CONTROL_PERMISSIVE_MODE = 802;

    /**
     * Construct an instance of this class.
     *
     * @param defaultValue the initial value of the parental control setting (must be one of the constants defined in this class).
     */
    protected ParentalControlLevel(int defaultValue) {
    }


    /**
     * Get the parental control value; this is one of the values defined in this class.
     *
     * @return the parental control level.
     */
    public int getValue() {
        return 0;
    }

    /**
     * Set the parental control level, which can be one of the levels defined as constants in this class.
     * This allows the user to set which kind of PPV events should require an extra PIN input for viewing.
     *
     * @param value the new parental control level.
     */
    public void setValue(int value) {
    }

    /**
     * Informs whether an extra PIN input is required for viewing all PPV events rated as indicated.
     *
     * @param rating the PPV event rating (@see Rating)
     * @return TRUE if an extra PIN input is required for this rate
     */
    public boolean isPinRequired(ContentRatingAdvisory rating) {
        return false;
    }

}
